# Design React Kit

[![Join channel #design-devel](https://img.shields.io/badge/Slack%20channel-%23design--devel-blue.svg)](https://developersitalia.slack.com/messages/C7VPAUVB3/)
[![Get an invitation for Slack](https://slack.developers.italia.it/badge.svg)](https://slack.developers.italia.it/)

*Read this in other languages: [Italiano](README.md).*

## Intro

**Design React kit** is a set of React components that implements [Bootstrap Italia](https://italia.github.io/bootstrap-italia/) and [Design UI Kit](https://github.com/italia/design-ui-kit) styling, as [shown on InVision](https://invis.io/TWMUZS6VFP5).

Components are showcased with [Storybook](https://storybook.js.org/).

Public version of Storybook (built from `master` branch) is available here: https://italia.github.io/design-react-kit.

## Table of contents

<!-- START TOC generated by doctoc please keep a comment here to allow automatic updating -->
<!-- DO NOT MODIFY THIS SECTION, INSTEAD RE-RUN doctoc TO UPDATE -->

- [Requirements](#requirements)
- [Getting Started](#getting-started)
- [How to create new components](#how-to-create-new-components)
  - [Storybook](#storybook)
- [Publishing](#publishing)
  - [Package](#package)
    - [Peer dependencies](#peer-dependencies)
    - [CSS Styles](#css-styles)
    - [Preprocessors](#preprocessors)
- [Continuous integration](#continuous-integration)
  - [`build` job](#build-job)
  - [`deploy-github-pages` job](#deploy-github-pages-job)
  - [`npm-publish` job](#npm-publish-job)

<!-- END doctoc generated TOC please keep the comment here to allow automatic updating -->

### Requirements

* NodeJS
* Yarn

## Getting started

Clone the repo and run `yarn` to install the dependencies.
Then run the `yarn storybook:serve` command to start the development server.

Storybook will therefore be available at http://localhost:9001/

![storybook](/assets/storybook-screenshot.jpg?raw=true)

Public version of the Storybook is available [here](https://italia.github.io/design-react-kit).

## How to create new components

This section explains how to create new components in the repository.
All components reside in the `components` directory: each component is a folder with all that is needed to make it work. *Storybook* stories are instead under `stories`.

i.e. the `Button` component is shown below the `src/components/Button` path and its structure is as follows:

```
src
    └── components
        └── Button
            ├── Button.js
stories
    └── Button
        ├── Button.stories.js
```

Some basic rules for structuring the components:

* JS file component files use JSX syntax.
* The `.stories.js` files only restore the relative component only.

Once you have created a new component, with its history, starting *Storybook* will be able to check that everything works as it should.

### Storybook

Storybook has been enriched with some `addons` that make it more talented. Check dependencies on the `package.json` file for details.

## Publishing

A command is available to reach a static version of the Storybook catalog as it can be deployed without using a webserver.

```sh
$ yarn run storybook
```

Static pages obtained from the compilation process generate under the `storybook-static` directory.

### Package

To use Design React as a dependency in an app you can install it from [npm](https://www.npmjs.com/~italia):

```sh
$ npm install design-react-kit
```

Then, you need to import CSS e font (already included in the `design-react-kit` npm package) as shown:

```jsx
import React from 'react';
import { Alert } from 'design-react-kit';
import 'bootstrap-italia/dist/css/bootstrap-italia.min.css';
import 'typeface-titillium-web';
import 'typeface-roboto-mono';
import 'typeface-lora';

const Example = () => {
  return (
    <Alert>
        Questo è un alert
    </Alert>
  );
};
```

#### Peer dependencies

The library does not include `react` and `react-dom`, avoiding versions clashing and increasing the size of the bundle.
For this reason, for local development it will be necessary to manually install dependencies.

The command to be executed is
```sh
$ yarn install --peers
```
or alternatively manually
```sh
$ yarn install react react-dom
```
